//+------------------------------------------------------------------+
//|                                              RLCalculator_v1.mq4 |
//|                                Copyright 2012 - Dorian Ocsovszki |
//|                            http://ocsovszki-dorian.blogspot.com/ |
//|                                        Email: gorkhaan@gmail.com |
//|                                                                  |
//|                   Risk and Lot Calculator                        |
//|                  Version 1.1 - 2012.12.20.                       |
//|                                                                  |
//+------------------------------------------------------------------+

#property copyright "Copyright 2012 - Dorian Ocsovszki"
#property link      "http://ocsovszki-dorian.blogspot.com/"
#property indicator_chart_window

extern string Separator1 = "------ Indicator Settings ------";
extern bool   FollowPrice = false; // Following the Current ASK Price
extern bool   SetStopLosses = false; // Enable/Disable SetStopLoss Line and SetLongLoss Line
extern bool   SetTargetPrice = true; // Enable/Disable TargetPrice Line
extern double PipValue = 10; // Symbol() pip value
extern double RiskSlot1 = 2; // In percent
extern double RiskSlot2 = 1;


extern string Separator2 = "------ Display Settings ------";
extern color  ShortProfitStopLossColor = OrangeRed;
extern color  LongProfitStopLossColor = YellowGreen;
extern color  StopLossColor = Red;
extern color  CurrentPriceColor = Black;
extern color  TargetPriceColor = Green;
extern color  LabelTextColor = Black;
extern int    DisplayCorner = 2;
extern int    FontSize = 12;


//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
  
   if ( SetStopLosses ) {
      ObjectCreate("ShortProfitStopLoss", OBJ_HLINE, 0, Time[0], 1, 0, 0);
      ObjectCreate("LongProfitStopLoss", OBJ_HLINE, 0, Time[0], 1, 0, 0);
   }
   
   ObjectCreate("StopLoss", OBJ_HLINE, 0, Time[0], 1, 0, 0); 
   
   if ( SetTargetPrice ) {
      ObjectCreate("TargetPrice", OBJ_HLINE, 0, Time[0], 1, 0, 0);
      ObjectCreate("ProfitPip",OBJ_LABEL,0,0,0);
      ObjectCreate("RiskRewardRatio",OBJ_LABEL,0,0,0);
   }
   
   ObjectCreate("CurrentPrice", OBJ_HLINE, 0, Time[0], 1, 0, 0); 
   ObjectCreate("RiskPip",OBJ_LABEL,0,0,0);
      
   ObjectCreate("LotSlot1",OBJ_LABEL,0,0,0);
   ObjectCreate("LotSlot2",OBJ_LABEL,0,0,0);
   

   if ( SetStopLosses ) {
      ObjectSet("ShortProfitStopLoss",OBJPROP_COLOR,ShortProfitStopLossColor);
      ObjectSet("ShortProfitStopLoss",OBJ_HLINE,MarketInfo(Symbol(),MODE_ASK)+0.002);
      ObjectSet("ShortProfitStopLoss",OBJPROP_STYLE,STYLE_DOT);
         
      ObjectSet("LongProfitStopLoss",OBJPROP_COLOR,LongProfitStopLossColor);
      ObjectSet("LongProfitStopLoss",OBJ_HLINE,MarketInfo(Symbol(),MODE_ASK)-0.002);
      ObjectSet("LongProfitStopLoss",OBJPROP_STYLE,STYLE_DOT);
   }
      
   ObjectSet("StopLoss",OBJPROP_COLOR,StopLossColor);
   ObjectSet("StopLoss",OBJ_HLINE,MarketInfo(Symbol(),MODE_ASK)+0.0008);
   ObjectSet("StopLoss",OBJPROP_STYLE,STYLE_DOT);
 
   if ( SetTargetPrice ) {  
      ObjectSet("TargetPrice",OBJPROP_COLOR,TargetPriceColor);
      ObjectSet("TargetPrice",OBJ_HLINE,MarketInfo(Symbol(),MODE_BID)-0.0008);
      ObjectSet("TargetPrice",OBJPROP_STYLE,STYLE_DOT);
   }

   ObjectSet("CurrentPrice",OBJPROP_COLOR,CurrentPriceColor);
   ObjectSet("CurrentPrice",OBJ_HLINE,MarketInfo(Symbol(),MODE_BID));
   ObjectSet("CurrentPrice",OBJPROP_STYLE,STYLE_DOT);
     
   ObjectSet("RiskPip", OBJPROP_CORNER, DisplayCorner);
   if ( SetTargetPrice ) {
      ObjectSet("ProfitPip", OBJPROP_CORNER, DisplayCorner);
      ObjectSet("RiskRewardRatio", OBJPROP_CORNER, DisplayCorner);
   }
   ObjectSet("LotSlot1", OBJPROP_CORNER, DisplayCorner);
   ObjectSet("LotSlot2", OBJPROP_CORNER, DisplayCorner);
   
   
   ObjectSet("RiskPip", OBJPROP_YDISTANCE, 20);
   if ( SetTargetPrice ) {
      ObjectSet("ProfitPip", OBJPROP_YDISTANCE, 35);
      ObjectSet("RiskRewardRatio", OBJPROP_YDISTANCE, 50);
      
      ObjectSet("LotSlot1", OBJPROP_YDISTANCE, 75);
      ObjectSet("LotSlot2", OBJPROP_YDISTANCE, 90);
      
   } else {
      ObjectSet("LotSlot1", OBJPROP_YDISTANCE, 35);
      ObjectSet("LotSlot2", OBJPROP_YDISTANCE, 50);
      
   }
   
//---- indicators
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   if ( SetStopLosses ) {
      ObjectDelete("ShortProfitStopLoss");
      ObjectDelete("LongProfitStopLoss");
   }
   ObjectDelete("StopLoss");
   ObjectDelete("CurrentPrice");
   if ( SetTargetPrice ) {
      ObjectDelete("TargetPrice");
   }
   ObjectDelete("RiskPip");
   ObjectDelete("ProfitPip");
   ObjectDelete("RiskRewardRatio");
   ObjectDelete("LotSlot1");
   ObjectDelete("LotSlot2");
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
//----

double RiskInMoney[] = {0, 0, 0, 0, 0, 0};
double AchiveableProfit[] = {0, 0, 0, 0, 0, 0};

double SLValue = 0;
double CPValue = 0;
double TPValue = 0;

double LotSizeSlot1 = 0;
double LotSizeSlot2 = 0;


double RiskPips = 0;
double ProfitPips = 0;
double RiskRewardRatio=0;

SLValue = ObjectGet("StopLoss",OBJPROP_PRICE1);
if (FollowPrice == true){
      ObjectSet("CurrentPrice",OBJ_HLINE,MarketInfo(Symbol(),MODE_BID));
      CPValue = ObjectGet("CurrentPrice",OBJPROP_PRICE1);
} else {
      CPValue = ObjectGet("CurrentPrice",OBJPROP_PRICE1);
}

if ( SetTargetPrice ) {
   TPValue = ObjectGet("TargetPrice",OBJPROP_PRICE1);
}



//+------------------------------------------------------------------+
//|      MODIFY CODE HERE REGARDING TO YOUR BROKER'S SETTINGS        |
//|                                                                  |
//| For example:   "GOLD" quote for FxPro                            |
//|                "XAUUSD" quote for AlpariFS                       |
//|                                                                  |
//+------------------------------------------------------------------+

if (Symbol() == "XAUUSD" || Symbol() == "GOLD" || Symbol() == "GOLDEURO") {
   RiskPips = MathAbs((SLValue - CPValue) * 10);
   if ( SetTargetPrice ) {
      ProfitPips = MathAbs((TPValue - CPValue) * 10);
      RiskRewardRatio = ProfitPips / RiskPips;
   }
} else if (Symbol() == "GBPJPY" || Symbol() == "USDJPY" || Symbol() == "EURJPY") { 
   RiskPips = MathAbs((SLValue - CPValue) * 100);
   if ( SetTargetPrice ) {
      ProfitPips = MathAbs((TPValue - CPValue) * 100);
      RiskRewardRatio = ProfitPips / RiskPips;
   }
} else {
   RiskPips = MathAbs((SLValue - CPValue) * 10000);
   if ( SetTargetPrice ) {
      ProfitPips = MathAbs((TPValue - CPValue) * 10000);
      RiskRewardRatio = ProfitPips / RiskPips;
   }
}

//+------------------------------------------------------------------+
//|      MODIFY CODE HERE REGARDING TO YOUR BROKER'S SETTINGS        |
//+------------------------------------------------------------------+




// Calculating Risk in Money
RiskInMoney[0] = AccountBalance() * (RiskSlot1 / 100);
RiskInMoney[1] = AccountBalance() * (RiskSlot2 / 100);

// Calculating Lot sizes
LotSizeSlot1 = (RiskInMoney[0] / RiskPips) / PipValue;
LotSizeSlot2 = (RiskInMoney[1] / RiskPips) / PipValue;


// Achiveable Profit
if ( SetTargetPrice ) {
   AchiveableProfit[0] = LotSizeSlot1 * ProfitPips * PipValue;
   AchiveableProfit[1] = LotSizeSlot2 * ProfitPips * PipValue;
   
}

ObjectSetText("RiskPip", "Risked Pips:     " +DoubleToStr(RiskPips,3), FontSize, "Arial" ,LabelTextColor);
if ( SetTargetPrice ) {
   ObjectSetText("ProfitPip", "Profitable Pips:     " +DoubleToStr(ProfitPips,3), FontSize, "Arial" ,LabelTextColor);
   ObjectSetText("RiskRewardRatio", "Risk/Reward Ratio:     " +DoubleToStr(RiskRewardRatio,3), FontSize, "Arial" ,LabelTextColor);

   ObjectSetText("LotSlot1", DoubleToStr(RiskSlot1,1)+ "%  risk is  $"+ DoubleToStr(RiskInMoney[0],2)+ "  using  " +DoubleToStr(LotSizeSlot1,3)+ " lot   [ $"+DoubleToStr(AchiveableProfit[0],2)+ " ]", FontSize, "Arial" ,LabelTextColor);
   ObjectSetText("LotSlot2", DoubleToStr(RiskSlot2,1)+ "%  risk is  $"+ DoubleToStr(RiskInMoney[1],2)+ "  using  " +DoubleToStr(LotSizeSlot2,3)+ " lot   [ $"+DoubleToStr(AchiveableProfit[1],2)+ " ]", FontSize, "Arial" ,LabelTextColor);
   
} else {

   ObjectSetText("LotSlot1", DoubleToStr(RiskSlot1,1)+ "%  risk is  $"+ DoubleToStr(RiskInMoney[0],2)+ "  using  " +DoubleToStr(LotSizeSlot1,3)+ " lot", FontSize, "Arial" ,LabelTextColor);
   ObjectSetText("LotSlot2", DoubleToStr(RiskSlot2,1)+ "%  risk is  $"+ DoubleToStr(RiskInMoney[1],2)+ "  using  " +DoubleToStr(LotSizeSlot2,3)+ " lot", FontSize, "Arial" ,LabelTextColor);
   
}

//----
   return(0);
  }
//+------------------------------------------------------------------+